<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=he
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'החלף את ה-PLUGIN',
	'affichage' => 'הצגה',
	'aide_non_disponible' => 'חלק זה מהעזרה אונליין אינו עדיין מוכן בשפה זו.',
	'auteur' => 'כותב',
	'avis_acces_interdit' => 'גישה אסורה',
	'avis_article_modifie' => 'אזהרה, @nom_auteur_modif@ עבד על הכתבה הזאת @date_diff@ לפני דקות אחדות',
	'avis_aucun_resultat' => '.שום תוצאות לא נמצאו',
	'avis_base_inaccessible' => 'אי אפשר להתחבר לנדבך נתונים données @base@.',
	'avis_chemin_invalide_1' => 'הנתיב שבחרת',
	'avis_chemin_invalide_2' => 'לא נראה בר תוקף. נא לחזור לדף הקודם ולוודא את האינפורמציה.',
	'avis_connexion_echec_1' => 'התקשרות לבסיס הנתונים נכשלה',
	'avis_connexion_echec_2' => 'נא לחזור לדף הקודם ולוודא את האינפורמציה. ',
	'avis_connexion_echec_3' => '<b>N.B.</b> על מספר שרתים, אתה חייב <b>בקשה</b> ההפעלה של הגישה שלך לבסיס הנתונים של מיי.אס.קיו.אל לפני שתוכל להשתמש בו. אם אינך יכול להתחבר, וודא שלמעשה שלחת את הבקשה הזאת ',
	'avis_connexion_ldap_echec_1' => 'התקשרות לשרת אל.די.איי.פי נכשלה',
	'avis_connexion_ldap_echec_2' => 'חזור אל הדף הקודם וודא את האינפורמציה שסיפקת',
	'avis_connexion_ldap_echec_3' => 'לחלופין, אל תשתמש בתמיכת אל.די.איי.פי  לייבא משתמשים ', # MODIF
	'avis_deplacement_rubrique' => ' אזהרה ! המדור הזה כולל @contient_breves@ brève@scb@ : אם הנך מזיז אותו, וודא שהנך מסמן את התיבה הזאת לאישור.',
	'avis_erreur_connexion_mysql' => 'שגיאת התחברות לאס.קיו.אל',
	'avis_espace_interdit' => '<b>Forbidden area</b><p>אס.פי.אי.פי כבר מותקן', # MODIF
	'avis_lecture_noms_bases_1' => 'תוכנת ההתקנה לא יכולה לקרוא את שמות בסיסי הנתונים המותקנים ',
	'avis_lecture_noms_bases_2' => 'או שאף בסיס אינו נגיש , או שהפונקציה המאפשרת לערוך רשימה של הבסיסים אינה פעילה יותר
 מסיבות בטיחות (מקרה הקורה אצל הרבה שרתי אכסון).',
	'avis_lecture_noms_bases_3' => 'במידה והחלופה השנייה הייתה נכונה, ישנה אפשרות שבסיס הנתונים שנקרא אחרי כניסתך למערכת יכול להיות שימושי: ',
	'avis_non_acces_page' => 'אינך חייב להכנס לדף הזה',
	'avis_operation_echec' => 'הפעולה נכשלה',
	'avis_operation_impossible' => 'פעולה אינה אפשרית',
	'avis_suppression_base' => 'אזהרה, מחיקת המידע היא פעולה בלתי הפיכה ',

	// B
	'bouton_acces_ldap' => ' הוסף גישה ל-LDAP',
	'bouton_ajouter' => 'הוסף',
	'bouton_annuler' => 'בטל',
	'bouton_demande_publication' => 'בקשה להופיע את המאמר',
	'bouton_desactive_tout' => 'בטל פעולה של הכל',
	'bouton_desinstaller' => 'הסר',
	'bouton_effacer_tout' => 'מחיקת הכל',
	'bouton_envoyer_message' => 'הודעה סופית : שלח',
	'bouton_fermer' => 'סגור',
	'bouton_mettre_a_jour_base' => 'עכדן נדבך נתונים',
	'bouton_modifier' => 'תיקון',
	'bouton_radio_afficher' => 'הראה',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'הופיע ברשימת העורכים המחוברים', # MODIF
	'bouton_radio_envoi_annonces_adresse' => ':שליחת הודעות לכתובת',
	'bouton_radio_envoi_liste_nouveautes' => 'שלח את רשימת החדשות האחרונה',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'אל תופיע ברשימת העורכים המחוברים', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'אל תשלח הודעות עורך ',
	'bouton_redirection' => 'כוון שנית',
	'bouton_relancer_installation' => 'התחל בשנית התקנה',
	'bouton_suivant' => 'הבא',
	'bouton_tenter_recuperation' => 'ניסיון תיקון',
	'bouton_test_proxy' => 'בחן את ייפוי הכוח',
	'bouton_vider_cache' => '(לרוקן את המחבוא(מטמון',

	// C
	'cache_modifiable_webmestre' => 'הפרמטר הזה ניתן לשינוי על ידי מנהל האתר', # MODIF
	'calendrier_synchro' => 'אם אתה משתמש באפליקציית יומן תואמת עם <b>iCal</b>, אתה יכול לסנכרן את זה עם אינפורמציה של אתרים אחרים',
	'config_activer_champs' => 'הפעל את השדות הבאים',
	'config_choix_base_sup' => 'ציין בסיס נתונים על שרת זה',
	'config_erreur_base_sup' => 'אין ל-SPIP גישה לרשימת בסיסי הנתונים הנגישים',
	'config_info_base_sup' => 'אם יש לך בסיסי נתונים אחרים שאתה רוצה להתיעץ בהם באמצעות SPIP, על ידי השרת שלה SQL או על ידי אחר, השאלון למטה מאפשר לך להציג אותם. אם אתה משאיר שדות ריקים, המזהים של ההתקשרות לבסיס העיקרי יהיו בשימוש.',
	'config_info_base_sup_disponibles' => 'ניתן להציג שאלות לבסיס הנוסף ',
	'config_info_enregistree' => 'התצורה החדשה נשמר',
	'config_info_logos' => 'כל אלמנט באתר יכול לשאת לוגו, כך גם « logo de survol »',
	'config_info_logos_utiliser' => 'השתמש בלוגואים',
	'config_info_logos_utiliser_non' => 'אל תשתמש בלוגואים',
	'config_info_logos_utiliser_survol' => 'השתמש בלוגואים של העלעול',
	'config_info_logos_utiliser_survol_non' => 'אל תשתמש בלוגואים של העלעול',
	'config_info_redirection' => 'על ידי הפעלת האופציה הזאת, אתה יכול ליצור מאמרים וירטואלים, הפניות פשוטות למאמרים המפורסמים באתרים אחרים או מחוץ ל-SPIP',
	'config_redirection' => 'מאמרים וירטואלים',
	'config_titre_base_sup' => 'הצהרה של בסיס נתונים נוסף',
	'config_titre_base_sup_choix' => 'בחר בסיס נתונים נוסף',
	'connexion_ldap' => 'התחברות:',

	// D
	'date_mot_heures' => '"H"',

	// E
	'email' => 'דוא"ל',
	'email_2' => 'דוא"ל:',
	'entree_adresse_annuaire' => 'מען המדריך',
	'entree_adresse_email' => 'הדוא"ל שלך',
	'entree_adresse_email_2' => 'כתובת דוא"ל',
	'entree_base_donnee_1' => 'כתובת בסיס הנתונים',
	'entree_base_donnee_2' => '(לעיתים הכתובת מתאימה לזאת של אתרך, לפעמים היא מתאימה למושג «localhost»,לפעמים היא מושארת לגמרי ריקה).',
	'entree_biographie' => 'ביוגרפיה קצרה בכמה מילים',
	'entree_chemin_acces' => '<b>Enter</b> את הדרך:',
	'entree_cle_pgp' => 'מפתח ה-פי.ג’י.פי שלך',
	'entree_contenu_rubrique' => '(תוכן המדור בכמה מילים.)',
	'entree_identifiants_connexion' => '...מזהי ההתחברות שלך',
	'entree_identifiants_connexion_2' => 'מזהה של חיבור',
	'entree_informations_connexion_ldap' => 'נא מלא את התבנית הזאת עם אינפורמציית התקשרות ה-אל.די.איי.פי. אתה תהיה מוענק עם האינפורמציה הזאת על ידי מנהל הרשת או המערכת.', # MODIF
	'entree_infos_perso' => '?מי אתה',
	'entree_infos_perso_2' => 'מי המחבר?',
	'entree_interieur_rubrique' => 'בתוך המדור:',
	'entree_liens_sites' => '<b>קישור היפרטקסט</b> (התיחסות, אתר לבקר...)',
	'entree_login' => 'שם ההתחברות שלך',
	'entree_login_connexion_1' => 'שם ההתחברות של החיבור',
	'entree_login_connexion_2' => '(מתייחס לעיתים ל-LOGIN הגישה שלך ל-FTP, לפעמים הוא מושאר ריק)',
	'entree_mot_passe' => 'סיסמתך',
	'entree_mot_passe_1' => 'סיסמת התחברות',
	'entree_mot_passe_2' => '(מתייחס לעיתים לסיסמה שלך על ה-FTP, לפעמים מושאר ריק)',
	'entree_nom_fichier' => 'נא רשום את שם הקובץ@texte_compresse@:',
	'entree_nom_pseudo' => 'שם או כינוי',
	'entree_nom_pseudo_1' => '(שם או כינוי)',
	'entree_nom_pseudo_2' => 'שם או כינוי',
	'entree_nom_site' => 'השם של האתר שלך',
	'entree_nouveau_passe' => 'סיסמה חדשה',
	'entree_passe_ldap' => 'סיסמה',
	'entree_port_annuaire' => 'מספר יציאה של המדריך',
	'entree_signature' => 'חתימה',
	'entree_titre_obligatoire' => '<b>כותרת</b> [הכרחי]<br />',
	'entree_url' => 'הכתובת הכללית של האתר שלך',
	'erreur_plugin_fichier_absent' => 'קובץ חסר',
	'erreur_plugin_fichier_def_absent' => 'קובץ בעל הגדרה חסרה',
	'erreur_plugin_nom_fonction_interdit' => 'שם פונקציה אסור',
	'erreur_plugin_nom_manquant' => 'שם PLUGIN חסר',
	'erreur_plugin_prefix_manquant' => 'אזור קריאת שם PLUGIN לא מוגדר',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; חסר בקובץ ההגדרה',
	'erreur_plugin_version_manquant' => 'גרסת PLUGIN חסרה',

	// I
	'ical_info1' => 'הדף הזה מציג כמה שיטות לשמור קשר עם פעילות האתר הזה.',
	'ical_info2' => 'ליותר פרטים על כל הטכניקות, אל תהסס לפנות ל המסמכים של <<a href="@spipnet@">SPIP </a',
	'ical_info_calendrier' => 'שני לוחות זמנים נמצאים בסל האשפה. הראשון הוא מפת אתר אשר מראה את כל הכתבות המפורסמות. השני מכיל הודעות עורכים גם ההודעות הפרטיות האחרונות שלך: זה שמור בשבילך הודות למפתח אישי שאתה יכול לשנות בכל זמן על ידי חידוש סיסמתך.',
	'ical_methode_http' => 'מוריד',
	'ical_methode_webcal' => 'סינכרוניזציה (webcal://)', # MODIF
	'ical_texte_prive' => 'לוח הזמנים זה, לשימוש פרטי בלבד, מיידע אותך על הפעילות הפרטית של העורכים של האתר הזה (משימות, פגישות אישיות, מאמרים ומבזקים מוצעים...).',
	'ical_texte_public' => 'לוח הזמנים זה מאפשר לך לעקוב אחר הפעילות הציבורית של האתר הזה (מאמרים מפורסמים ומבזקים). ',
	'ical_texte_rss' => 'הינך יכול לעשות סינדיקציה על החדשות האחרונות של האתר הזה בכל אקס.אמ.אל/אר.אס.אס (סיכום עשיר של אתר) קורא קבצים. כמו כן זה גם הפורמט שמאפשר ל אס.פי.איי.פי לקרוא את החדשות האחרונות שמפורסמות על ידי אתרים אחרים אשר משתמשים בחילוף תואם של פורמטים (אתרים בעלי סינדיקציה)',
	'ical_titre_js' => 'Javascript (שפת ג’אווה)',
	'ical_titre_mailing' => 'רשימת דואר',
	'ical_titre_rss' => 'קבצי איסוף תכני רשת',
	'icone_activer_cookie' => '"מקם "קוקיי',
	'icone_admin_plugin' => 'ניהול ה-PLUGINS',
	'icone_afficher_auteurs' => 'הצג מחברים',
	'icone_afficher_visiteurs' => 'הצג מבקרים',
	'icone_arret_discussion' => 'הפסק השתתפות בשיחה זו',
	'icone_calendrier' => 'לוח שנה',
	'icone_creer_auteur' => 'צור מחבר חדש ושתף אותו עם המאמר הזה',
	'icone_creer_mot_cle' => 'צור מילת מפתח חדשה וצור לה קישור עם המאמר הזה',
	'icone_creer_rubrique_2' => 'צור מדור חדש',
	'icone_modifier_article' => 'שנה את המאמר הזה',
	'icone_modifier_rubrique' => 'תיקון מדור',
	'icone_relancer_signataire' => 'העלה מחדש את החתום',
	'icone_retour' => 'אחורה',
	'icone_retour_article' => 'אל המאמר הקודם',
	'icone_supprimer_cookie' => '"מחק "קוקיי',
	'icone_supprimer_rubrique' => 'מחיקת המדור',
	'icone_supprimer_signature' => 'מחק חתימה זו',
	'icone_valider_signature' => 'תן תוקף לחתימה זו',
	'image_administrer_rubrique' => 'אתה יכול לנהל את המדור',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => 'מאמר 1',
	'info_activer_cookie' => 'אתה יכול להפעיל <b> עוגיית התכתבות</b>, אשר יאפשר לך
 לעבור בקלות מן האתר הציבורי לאתר הפרטי.',
	'info_administrateur' => 'מנהל', # MODIF
	'info_administrateur_1' => 'מנהל', # MODIF
	'info_administrateur_2' => 'של האתר (<i>use with caution</i>)',
	'info_administrateur_site_01' => 'אם היך מנהל אתר, אנא', # MODIF
	'info_administrateur_site_02' => 'לחץ על הקישור הזה',
	'info_administrateurs' => 'מנהלים', # MODIF
	'info_administrer_rubrique' => 'הינך יכול לנהל מדור זה',
	'info_adresse' => ':אל הכתובת',
	'info_adresse_url' => 'הכתובת הכללית של האתר הציבורי שלך',
	'info_aide_en_ligne' => 'עזרה מקוונת ל-אס.פי.אי.פי',
	'info_ajout_image' => 'כאשר אתה מוסיף תמונות כמסמכים מצורפים למאמר,
 SPIP יכול ליצור עבורך, בצורה אוטומטית, מיניאטורות של
 תמונות מוכנסות. הדבר מאפשר למשל ליצור
 אוטומטית גלריה או תיק עבודות.',
	'info_ajouter_rubrique' => 'הוספת מדור נוסף לניהול:',
	'info_annonce_nouveautes' => 'מודעות אחרונות של חדשות',
	'info_article' => 'מאמר',
	'info_article_2' => 'מאמרים',
	'info_article_a_paraitre' => 'המאמרים בעלי תאריך מאוחר שיופיעו',
	'info_articles_02' => 'מאמרים',
	'info_articles_2' => 'מאמרים',
	'info_articles_auteur' => 'המאמרים של המחבר הזה',
	'info_articles_trouves' => 'מאמרים נמצאו',
	'info_attente_validation' => 'המאמרים שלך מחכים למתן תוקף',
	'info_aujourdhui' => ':היום',
	'info_auteurs' => 'מחברים',
	'info_auteurs_par_tri' => 'מחברים@partri@',
	'info_auteurs_trouves' => 'מחברים נמצאו',
	'info_authentification_externe' => 'אישור חיצוני',
	'info_avertissement' => 'אזהרה',
	'info_barre_outils' => 'עם סרגל הכלים שלי?',
	'info_base_installee' => '.המבנה של בסיס הנתונים שלך מותקן',
	'info_chapeau' => 'סיפון',
	'info_chapeau_2' => ':הקדמה',
	'info_chemin_acces_1' => 'אפשרויות: <b>Access path in directory</b>',
	'info_chemin_acces_2' => 'מעכשיו והלאה, הינך חייב לעצב את דרך הגישה לספריית המידע. המידע הזה נחוץ לקריאת הפרופילים של המשתמשים אשר שמורים בספרייה.', # MODIF
	'info_chemin_acces_annuaire' => 'אפשרויות: <b>Access path in directory</b>',
	'info_choix_base' => ':שלב שלישי',
	'info_classement_1' => '<sup>st</sup> מחוץ ל @liste@',
	'info_classement_2' => '<sup>th</sup> מחוץ ל @liste@',
	'info_code_acces' => '!אל תשכח את את קודי הגישה שלך',
	'info_config_suivi' => 'אם הכתובת הזאת מותאמת לרשימת דיוור,  אתה יכול לציין להלן את הכתובת איפה שמשתתפי האתר יכולים להרשם. הכתובת הזאת יכולה להיות כתובת כללית (למשל העמוד של רשימת הרישום דרך הרשת), או כתובת דוא"למעונקת עם נושא מסויים (למשל: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'הינך יכול להירשם לרשימת הדיוור של האתר. לאחר הרישום תקבל, על ידי דואר אלקטרוני, את המודעות באשר למאמרים ולמבזקים המוצעים לפרסום.',
	'info_confirmer_passe' => ':אשר סיסמה חדשה',
	'info_connexion_base' => 'שלב שני: <b>Attempting to connect to database</b>',
	'info_connexion_mysql' => 'שלב ראשון: <b>Your SQL connection</b>',
	'info_connexion_ok' => '.התקשרות הצליחה',
	'info_contact' => 'התקשר',
	'info_contenu_articles' => 'תוכן המאמרים',
	'info_creation_paragraphe' => '(בשביל ליצור פסקאות, אתה פשוט עוזב שורות ריקות.)', # MODIF
	'info_creation_rubrique' => 'לפני שתוכל לכתוב מאמרים,<br />אתה חייב ליצור לפחות פדור אחד<br />',
	'info_creation_tables' => 'שלב רביעי: <b>Creation of the database tables</b>',
	'info_creer_base' => '<b>Create</b> בסיס נתונים חדש :',
	'info_dans_rubrique' => 'במדור:',
	'info_date_publication_anterieure' => 'תאריך של הוצאה לאור מוקדמת:',
	'info_date_referencement' => ':תאריך של הוספת מראי מקום באתר זה',
	'info_derniere_etape' => 'זהו הסתיים!',
	'info_descriptif' => ':תיאור',
	'info_discussion_cours' => 'דיונים בהתקדמות',
	'info_ecrire_article' => 'לפני שתוכל לכתוב מאמרים, אתה חייב ליצור לפחות מדור אחד.',
	'info_email_envoi' => '(כתובת הדוא"ל של השולח (רשות',
	'info_email_webmestre' => '(כתובת הדוא"ל של מומחה הרשת (רשות', # MODIF
	'info_envoi_email_automatique' => 'דיוור אוטומטי',
	'info_envoyer_maintenant' => 'שלח עכשיו',
	'info_etape_suivante' => 'לך אל השלב הבא',
	'info_etape_suivante_1' => '.הינך יכול לעבור לשלב הבא',
	'info_etape_suivante_2' => '.הינך יכול לעבור לשלב הבא',
	'info_exportation_base' => 'יצוא בסיס נתונים אל @archive@',
	'info_fichiers_authent' => '".htpasswd" אישור קובץ',
	'info_gauche_auteurs_exterieurs' => 'מחברים חיצוניים, ללא שום גישה לאתר, מצויינים על ידי סמל כחול; מחברים מחוקים על ידי פח אשפה.', # MODIF
	'info_gauche_messagerie' => 'התכתבות מאפשרת לך להחליף הודעות בין עורכים, כדי לשמר תזכירים (לשימושך האישי) או להציג מודעות בדף הבית של (.האזור הפרטי (אם אתה אחראי', # MODIF
	'info_gauche_statistiques_referers' => 'הדף הזה מציג רשימה של <i>referrers</i>, כלומר האתר מכיל קישורים לאתרך, רק להיום: למעשה הרשימה הזאת מתעדכנת כל 24 שעות.',
	'info_generation_miniatures_images' => 'יוצר תמונות ממוזערות',
	'info_hier' => ':אתמול',
	'info_identification_publique' => '...הזהות הציבורית שלך',
	'info_image_process2' => 'Si aucune image n’apparaît, alors le serveur qui héberge votre site n’a pas été configuré pour utiliser de tels outils. Si vous souhaitez utiliser ces fonctions, contactez le responsable technique et demandez les extensions « GD » ou « Imagick ».',
	'info_informations_personnelles' => 'נתונים אישיים',
	'info_inscription_automatique' => 'הרשמה אוטומטית של עורכים חדשים', # MODIF
	'info_jeu_caractere' => 'מערך תווים של האתר',
	'info_jours' => 'ימים',
	'info_laisser_champs_vides' => '(השאר את השדות האלה ריקים',
	'info_langues' => 'שפת האתר',
	'info_ldap_ok' => '.אישור אל.די.אי.פי מותקן',
	'info_lien_hypertexte' => ':קישור היפר טקסט',
	'info_liste_redacteurs_connectes' => 'רשימה של עורכים מחוברים', # MODIF
	'info_login_existant' => '.שם ההתחברות הזה תפוס',
	'info_login_trop_court' => '.שם ההתחברות יותר מדי קצר',
	'info_maximum' => ':מקסימום',
	'info_message_en_redaction' => 'ההודעות שלך בהתקדמות',
	'info_message_technique' => ':הודעה טכנית',
	'info_messagerie_interne' => 'התכתבות פנימית',
	'info_mise_a_niveau_base' => 'שדרוג בסיס הנתונים של מאי.אס.קיו.אל',
	'info_modifier_rubrique' => 'תיקון המדור הזה:',
	'info_modifier_titre' => 'שנה: @titre@',
	'info_mon_site_spip' => 'אתר ה-אס.פי.איי.פי שלי',
	'info_moyenne' => ':ממוצע',
	'info_multi_cet_article' => ':שפת המאמר הזה',
	'info_multi_secteurs' => '...רק למדורים הנמצאים בראשי?',
	'info_nom' => 'שם',
	'info_nom_destinataire' => 'שם המקבל',
	'info_nom_site' => 'שם האתר שלך',
	'info_nombre_articles' => '@nb_articles@ מאמרים,',
	'info_nombre_rubriques' => '@nb_rubriques@ מדורים,',
	'info_nombre_sites' => '@nb_sites@ אתרים,',
	'info_non_deplacer' => '...אל תזוז',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'ספיפ יכול לשלוח דרך הדוא"ל בקביעות הודעת החדשות של האתר
(מאמרים ומבזקים שפורסמו לארחונה).',
	'info_non_envoi_liste_nouveautes' => 'אל תשלח את רשימת החדשות האחרונה',
	'info_non_modifiable' => 'לא יכול להשתנות',
	'info_non_suppression_mot_cle' => '.אני לא רוצה למחוק את מילת המפתח הזאת',
	'info_notes' => 'הערת שוליים',
	'info_nouvel_article' => 'מאמר חדש',
	'info_nouvelle_traduction' => ':תרגום חדש',
	'info_numero_article' => ':מספר מאמר',
	'info_obligatoire_02' => '[מהווה חובה]', # MODIF
	'info_options_avancees' => 'אפשרויות מתקדמות',
	'info_ou' => '...או',
	'info_page_interdite' => 'דף אסור',
	'info_par_nom' => 'לפי שם',
	'info_par_nombre_article' => '(על ידי מספר מאמרים)',
	'info_passe_trop_court' => '.סיסמה קצרה מדי',
	'info_passes_identiques' => '.שתי הסימאות לא זהות',
	'info_plus_cinq_car' => 'יותר מ-5 תווים',
	'info_plus_cinq_car_2' => '(יותר מ-5 תווים)',
	'info_plus_trois_car' => '(יותר מ-3 תווים)',
	'info_popularite' => 'פופולריות: @popularite@; ביקורים: @visites@',
	'info_post_scriptum' => 'פוסטסקריפט',
	'info_post_scriptum_2' => ':פוסטסקריפט',
	'info_pour' => 'ל',
	'info_preview_texte' => 'אפשר לבקר את האתר בהקשפה מוקדמת כאילו כל המאמרים והמבזקים התפרסמו (עם לפחות הסטטוס "מוצע"). האם אתה רוצה להגיש אפשרות זו למנהלים בלבד, לכל מחברים או לכולם?', # MODIF
	'info_procedez_par_etape' => 'אנא המשך צעד אחר צעד',
	'info_ps' => 'נ.ב',
	'info_publier' => 'לפרסם',
	'info_publies' => 'המאמרים שלך מפורסמים ברשת',
	'info_racine_site' => 'בסיס האתר',
	'info_recharger_page' => '.אנא טען מחדש דף זה בעוד כמה רגעים',
	'info_recherche_auteur_zero' => 'אין תוצאות ל "@cherche_auteur@".',
	'info_recommencer' => '.אנא נסה שוב',
	'info_redacteur_1' => 'עורך',
	'info_redacteur_2' => 'מקבל אישור כניסה לאזור האישי (<i>recommended</i>)',
	'info_redacteurs' => 'עורכים',
	'info_redaction_en_cours' => 'עריכה בהתקדמות',
	'info_redirection' => 'הכוונה מחודשת',
	'info_refuses' => 'המאמרים שלך נדחו',
	'info_rubriques' => 'נושאים',
	'info_sans_titre' => 'בלי כותר',
	'info_site' => 'אתר אינטרנט',
	'info_site_2' => 'אתר אינטרנט :',
	'info_site_min' => 'אתר',
	'info_sites' => 'אתרים',
	'info_sous_titre' => 'כתוביות :',
	'info_statut_administrateur' => 'מנהל', # MODIF
	'info_surtitre' => 'הכותרת למעלה:',
	'info_texte' => 'טקסט',
	'info_texte_message' => 'הטקסט של ההודעה שלך :', # MODIF
	'info_total' => 'הכל :',
	'info_tous_les' => 'כל :',
	'info_tout_site' => 'כל האתר',
	'info_un_article' => 'פריט,',
	'info_un_site' => 'האתר,',
	'info_une_rubrique' => 'קטגוריה,',
	'info_url' => 'קישור :',
	'info_visiteur_1' => 'המבקר',
	'info_visiteur_2' => 'אתר ציבורי',
	'info_visiteurs' => 'מבקרים',
	'info_visiteurs_02' => 'המבקרים באתר את הציבור',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'intem_redacteur' => 'עורך',
	'item_administrateur_2' => 'מנהל', # MODIF
	'item_login' => 'הסינכ',
	'item_non' => 'לא',
	'item_nouvel_auteur' => 'מחבר חדש',
	'item_nouvelle_rubrique' => 'נושא חדש',
	'item_oui' => 'כן',

	// L
	'lien_email' => 'דואר אלקטרוני',
	'lien_site' => 'אתר',
	'logo_article' => 'למס מאמר', # MODIF
	'logo_auteur' => 'למס מחבר', # MODIF
	'logo_rubrique' => 'למס של כותרת', # MODIF
	'logo_site' => 'למס של אתר זה', # MODIF

	// M
	'module_raccourci' => 'קיצור דרך',

	// O
	'onglet_contenu' => 'תכות',
	'onglet_discuter' => 'לדון',
	'onglet_proprietes' => 'םינייפאמ',

	// P
	'plugin_info_automatique_ou' => 'או ...',
	'plugins_vue_liste' => 'רשימה',

	// R
	'repertoire_plugins' => 'ספריה :',
	'required' => '[מהווה חובה]', # MODIF

	// S
	'sans_heure' => 'בלי זמן',

	// T
	'taille_cache_vide' => 'האתר המטמון ריק.',
	'text_article_propose_publication' => 'במאמר מוצע לפרסום.',
	'texte_auteurs' => 'המחברים',
	'texte_compte_element' => '@count@ אלמנט',
	'texte_compte_elements' => '@count@ אלמנטים',
	'texte_sous_titre' => 'כתובית',
	'texte_statut_attente_validation' => 'אימות ממתינים',
	'texte_statut_publies' => 'שפורסם באינטרנט',
	'texte_statut_refuses' => 'סירב',
	'texte_sur_titre' => 'על כותרת',
	'texte_titre_02' => 'כותר :',
	'texte_vide' => 'ריק',
	'titre_langue_article' => 'שפת המאמר',
	'titre_langue_rubrique' => 'שפת המדור',
	'titre_page_articles_page' => 'מאמרים',
	'titre_page_articles_tous' => 'כל האתר',
	'titre_reparation' => 'תיקון',
	'trad_delier' => 'לא לקשור את המאמר לתרגומיו',
	'trad_new' => 'כתיבת תרגום חדש של המאמר',

	// V
	'version' => 'מספר :',
];
